aboutsummaryrefslogtreecommitdiff
path: root/arch
diff options
context:
space:
mode:
Diffstat (limited to 'arch')
-rw-r--r--arch/x86_64/include/arch/memory/paging/kernel_mapper.hpp8
-rw-r--r--arch/x86_64/include/arch/memory/paging/page_entry.hpp2
-rw-r--r--arch/x86_64/src/memory/paging/page_entry.cpp2
3 files changed, 6 insertions, 6 deletions
diff --git a/arch/x86_64/include/arch/memory/paging/page_entry.hpp b/arch/x86_64/include/arch/memory/paging/page_entry.hpp
index 6ee1a13..03cdb1a 100644
--- a/arch/x86_64/include/arch/memory/paging/page_entry.hpp
+++ b/arch/x86_64/include/arch/memory/paging/page_entry.hpp
@@ -75,7 +75,7 @@ namespace teachos::arch::memory::paging
* @brief Marks the page as accessible in User mode, meaning the underlying std::bitset has the 2nd bit aditonally
* set.
*/
- auto set_user_accesible() -> void;
+ auto set_user_accessible() -> void;
auto set_global() -> void;
diff --git a/arch/x86_64/src/memory/paging/page_entry.cpp b/arch/x86_64/src/memory/paging/page_entry.cpp
index 57e33f7..a5b44fa 100644
--- a/arch/x86_64/src/memory/paging/page_entry.cpp
+++ b/arch/x86_64/src/memory/paging/page_entry.cpp
@@ -37,7 +37,7 @@ namespace teachos::arch::memory::paging
auto entry::set_unused() -> void { flags = 0U; }
- auto entry::set_user_accesible() -> void { flags |= entry::USER_ACCESSIBLE; }
+ auto entry::set_user_accessible() -> void { flags |= entry::USER_ACCESSIBLE; }
auto entry::set_global() -> void { flags |= entry::GLOBAL; }
diff --git a/arch/x86_64/include/arch/memory/paging/kernel_mapper.hpp b/arch/x86_64/include/arch/memory/paging/kernel_mapper.hpp
index bc36361..7321548 100644
--- a/arch/x86_64/include/arch/memory/paging/kernel_mapper.hpp
+++ b/arch/x86_64/include/arch/memory/paging/kernel_mapper.hpp
@@ -142,7 +142,7 @@ namespace teachos::arch::memory::paging
allocator::frame_container const frames{begin, end};
entry entry{section.flags};
// Required to be accesible in User Mode:
// - .boot_rodata (Contains constant data stored in ROM)
// - .boot_bss (Contains statically allocated variables)
// - .user_text (Contains the actual code executed)
@@ -152,20 +152,20 @@ namespace teachos::arch::memory::paging
section.physical_address == 0x102000 /* .boot_bss */ ||
section.physical_address == 0x218000 /* .stl_text */)
{
- entry.set_user_accesible();
+ entry.set_user_accessible();
entry.set_global();
}
// TODO: We should be able to remove this somehow
if (section.physical_address == 0x209000 /* .text */)
{
- entry.set_user_accesible();
+ entry.set_user_accessible();
}
if (section.physical_address == 0x217000 /* .user_text */ ||
section.physical_address == 0x21E000 /* .user_data */)
{
- entry.set_user_accesible();
+ entry.set_user_accessible();
}
for (auto const & frame : frames)
@@ -142,7 +142,7 @@ namespace teachos::arch::memory::paging
allocator::frame_container const frames{begin, end};
entry entry{section.flags};
- // Required to be accesible in User Mode:
+ // Required to be accessible in User Mode:
// - .boot_rodata (Contains constant data stored in ROM)
// - .boot_bss (Contains statically allocated variables)